@@ -42,6 +42,7 @@
 #include "absl/status/status.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/string_view.h"
+#include "src/core/call/metadata_batch.h"
 #include "src/core/channelz/channelz.h"
 #include "src/core/lib/channel/channel_stack.h"
 #include "src/core/lib/event_engine/event_engine_context.h"
@@ -57,7 +58,6 @@
 #include "src/core/lib/surface/completion_queue.h"
 #include "src/core/lib/surface/validate_metadata.h"
 #include "src/core/lib/transport/error_utils.h"
-#include "src/core/lib/transport/metadata_batch.h"
 #include "src/core/lib/transport/transport.h"
 #include "src/core/server/server_interface.h"
 #include "src/core/telemetry/call_tracer.h"
@@ -114,6 +114,7 @@ grpc_error_handle FilterStackCall::Create(grpc_call_create_args* args,
   *out_call = call->c_ptr();
   grpc_slice path = grpc_empty_slice();
   ScopedContext ctx(call);
+  Call* parent = Call::FromC(args->parent);
   if (call->is_client()) {
     call->final_op_.client.status_details = nullptr;
     call->final_op_.client.status = nullptr;
@@ -129,8 +130,15 @@ grpc_error_handle FilterStackCall::Create(grpc_call_create_args* args,
     call->send_initial_metadata_.Set(
         GrpcRegisteredMethod(), reinterpret_cast<void*>(static_cast<uintptr_t>(
                                     args->registered_method)));
-    channel_stack->stats_plugin_group->AddClientCallTracers(
-        Slice(CSliceRef(path)), args->registered_method, arena.get());
+    if (parent != nullptr) {
+      add_init_error(&error, absl_status_to_grpc_error(call->InitParent(
+                                 parent, args->propagation_mask)));
+    }
+    // Client call tracers should be created after propagating relevant
+    // properties (tracing included) from the parent.
+    (*channel_stack->stats_plugin_group)
+        ->AddClientCallTracers(Slice(CSliceRef(path)), args->registered_method,
+                               arena.get());
   } else {
     global_stats().IncrementServerCallsCreated();
     call->final_op_.server.cancelled = nullptr;
@@ -157,19 +165,14 @@ grpc_error_handle FilterStackCall::Create(grpc_call_create_args* args,
         arena->SetContext<CallTracerInterface>(server_call_tracer);
       }
     }
-    channel_stack->stats_plugin_group->AddServerCallTracers(arena.get());
+    (*channel_stack->stats_plugin_group)->AddServerCallTracers(arena.get());
   }
 
-  Call* parent = Call::FromC(args->parent);
-  if (parent != nullptr) {
-    add_init_error(&error, absl_status_to_grpc_error(call->InitParent(
-                               parent, args->propagation_mask)));
-  }
   // initial refcount dropped by grpc_call_unref
   grpc_call_element_args call_args = {
-      call->call_stack(),   args->server_transport_data, path,
-      call->start_time(),   call->send_deadline(),       call->arena(),
-      &call->call_combiner_};
+      call->call_stack(), args->server_transport_data,
+      call->start_time(), call->send_deadline(),
+      call->arena(),      &call->call_combiner_};
   add_init_error(&error, grpc_call_stack_init(channel_stack, 1, DestroyCall,
                                               call, &call_args));
   // Publish this call to parent only after the call stack has been initialized.
@@ -273,7 +276,7 @@ void FilterStackCall::ExternalUnref() {
   destroy_called_ = true;
   bool cancel = gpr_atm_acq_load(&received_final_op_atm_) == 0;
   if (cancel) {
-    CancelWithError(absl::CancelledError());
+    CancelWithError(absl::CancelledError("CANCELLED"));
   } else {
     // Unset the call combiner cancellation closure.  This has the
     // effect of scheduling the previously set cancellation closure, if
@@ -451,21 +454,31 @@ void FilterStackCall::RecvTrailingFilter(grpc_metadata_batch* b,
   } else {
     std::optional<grpc_status_code> grpc_status = b->Take(GrpcStatusMetadata());
     if (grpc_status.has_value()) {
-      grpc_status_code status_code = *grpc_status;
       grpc_error_handle error;
-      if (status_code != GRPC_STATUS_OK) {
-        Slice peer = GetPeerString();
-        error = grpc_error_set_int(
-            GRPC_ERROR_CREATE(absl::StrCat("Error received from peer ",
-                                           peer.as_string_view())),
-            StatusIntProperty::kRpcStatus, static_cast<intptr_t>(status_code));
-      }
-      auto grpc_message = b->Take(GrpcMessageMetadata());
-      if (grpc_message.has_value()) {
-        error = grpc_error_set_str(error, StatusStrProperty::kGrpcMessage,
-                                   grpc_message->as_string_view());
-      } else if (!error.ok()) {
-        error = grpc_error_set_str(error, StatusStrProperty::kGrpcMessage, "");
+      if (IsErrorFlattenEnabled()) {
+        auto grpc_message = b->Take(GrpcMessageMetadata());
+        absl::string_view message;
+        if (grpc_message.has_value()) message = grpc_message->as_string_view();
+        error =
+            absl::Status(static_cast<absl::StatusCode>(*grpc_status), message);
+      } else {
+        grpc_status_code status_code = *grpc_status;
+        if (status_code != GRPC_STATUS_OK) {
+          Slice peer = GetPeerString();
+          error = grpc_error_set_int(
+              GRPC_ERROR_CREATE(absl::StrCat("Error received from peer ",
+                                             peer.as_string_view())),
+              StatusIntProperty::kRpcStatus,
+              static_cast<intptr_t>(status_code));
+        }
+        auto grpc_message = b->Take(GrpcMessageMetadata());
+        if (grpc_message.has_value()) {
+          error = grpc_error_set_str(error, StatusStrProperty::kGrpcMessage,
+                                     grpc_message->as_string_view());
+        } else if (!error.ok()) {
+          error =
+              grpc_error_set_str(error, StatusStrProperty::kGrpcMessage, "");
+        }
       }
       SetFinalStatus(error);
     } else if (!is_client()) {
