@@ -19,18 +19,18 @@
 #include "src/core/lib/iomgr/resolve_address.h"
 
 #include <address_sorting/address_sorting.h>
-#include <gmock/gmock.h>
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/sync.h>
 #include <grpc/support/time.h>
-#include <gtest/gtest.h>
 #include <string.h>
 
 #include "absl/functional/bind_front.h"
 #include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/strings/match.h"
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
 #include "src/core/config/config_vars.h"
 #include "src/core/lib/iomgr/executor.h"
 #include "src/core/lib/iomgr/iomgr.h"
@@ -534,6 +534,11 @@ TEST_F(ResolveAddressTest, NativeResolverCannotLookupTXTRecords) {
 }
 
 int main(int argc, char** argv) {
+  if (grpc_core::IsPollsetAlternativeEnabled()) {
+    LOG(WARNING) << "iomgr resolver tests are disabled since the pollset "
+                    "alternative experiment breaks some iomgr APIs";
+    return 0;
+  }
   // Configure the DNS resolver (c-ares vs. native) based on the
   // name of the binary. TODO(apolcyn): is there a way to pass command
   // line flags to a gtest that it works in all of our test environments?
