@@ -34,8 +34,8 @@
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
 #include "src/core/config/core_configuration.h"
-#include "src/core/lib/security/certificate_provider/certificate_provider_factory.h"
-#include "src/core/lib/security/credentials/channel_creds_registry.h"
+#include "src/core/credentials/transport/channel_creds_registry.h"
+#include "src/core/credentials/transport/tls/certificate_provider_factory.h"
 #include "src/core/util/env.h"
 #include "src/core/util/json/json.h"
 #include "src/core/util/json/json_args.h"
@@ -60,21 +60,22 @@ MATCHER_P5(EqXdsServer, name, creds_config_type, ignore_resource_deletion,
                                      result_listener)) {
     return false;
   }
-  bool ok = ::testing::ExplainMatchResult(name, server->server_uri(),
+  bool ok = ::testing::ExplainMatchResult(name, server->target()->server_uri(),
                                           result_listener);
-  ok |=
+  ok &=
       ::testing::ExplainMatchResult(server->IgnoreResourceDeletion(),
                                     ignore_resource_deletion, result_listener);
-  ok |= ::testing::ExplainMatchResult(server->FailOnDataErrors(),
+  ok &= ::testing::ExplainMatchResult(server->FailOnDataErrors(),
                                       fail_on_data_errors, result_listener);
-  ok |= ::testing::ExplainMatchResult(server->TrustedXdsServer(),
+  ok &= ::testing::ExplainMatchResult(server->TrustedXdsServer(),
                                       trusted_xds_server, result_listener);
-  auto creds_config = server->channel_creds_config();
+  auto& server_target = DownCast<const GrpcXdsServerTarget&>(*server->target());
+  auto creds_config = server_target.channel_creds_config();
   if (!::testing::ExplainMatchResult(::testing::Ne(nullptr), creds_config,
                                      result_listener)) {
     return false;
   }
-  ok |= ::testing::ExplainMatchResult(creds_config_type, creds_config->type(),
+  ok &= ::testing::ExplainMatchResult(creds_config_type, creds_config->type(),
                                       result_listener);
   return ok;
 }
@@ -306,6 +307,25 @@ TEST(XdsBootstrapTest, NoKnownChannelCreds) {
       << bootstrap.status();
 }
 
+TEST(XdsBootstrapTest, MultipleCreds) {
+  const char* json_str =
+      "{"
+      "  \"xds_servers\": ["
+      "    {"
+      "      \"server_uri\": \"fake:///lb\","
+      "      \"channel_creds\": [{\"type\": \"unknown\"}, {\"type\": "
+      "\"fake\"}, {\"type\": \"insecure\"}]"
+      "    }"
+      "  ]"
+      "}";
+  auto bootstrap = GrpcXdsBootstrap::Create(json_str);
+  ASSERT_TRUE(bootstrap.ok()) << bootstrap.status();
+  EXPECT_THAT((*bootstrap)->servers(),
+              ::testing::ElementsAre(
+                  EqXdsServer("fake:///lb", "fake", false, false, false)));
+  EXPECT_EQ((*bootstrap)->node(), nullptr);
+}
+
 TEST(XdsBootstrapTest, MissingXdsServers) {
   auto bootstrap = GrpcXdsBootstrap::Create("{}");
   EXPECT_EQ(
@@ -699,33 +719,6 @@ TEST(XdsBootstrapTest, CertificateProvidersFakePluginEmptyConfig) {
   ASSERT_EQ(config->value(), 0);
 }
 
-TEST(XdsBootstrapTest, XdsServerToJsonAndParse) {
-  const char* json_str =
-      "    {"
-      "      \"server_uri\": \"fake:///lb\","
-      "      \"channel_creds\": ["
-      "        {"
-      "          \"type\": \"fake\","
-      "          \"ignore\": 0"
-      "        }"
-      "      ],"
-      "      \"ignore\": 0,"
-      "      \"server_features\": ["
-      "        \"fail_on_data_errors\","
-      "        \"ignore_resource_deletion\","
-      "        \"trusted_xds_server\""
-      "      ]"
-      "    }";
-  auto json = JsonParse(json_str);
-  ASSERT_TRUE(json.ok()) << json.status();
-  auto xds_server = LoadFromJson<GrpcXdsServer>(*json);
-  ASSERT_TRUE(xds_server.ok()) << xds_server.status();
-  Json output = xds_server->ToJson();
-  auto output_xds_server = LoadFromJson<GrpcXdsServer>(output);
-  ASSERT_TRUE(output_xds_server.ok()) << output_xds_server.status();
-  EXPECT_EQ(*xds_server, *output_xds_server);
-}
-
 TEST(XdsBootstrapTest, MultipleXdsServers) {
   const char* json_str =
       "{"
