@@ -43,8 +43,9 @@
 #include "absl/strings/str_format.h"
 #include "src/core/client_channel/backup_poller.h"
 #include "src/core/config/config_vars.h"
+#include "src/core/credentials/call/call_credentials.h"
+#include "src/core/lib/experiments/experiments.h"
 #include "src/core/lib/iomgr/iomgr.h"
-#include "src/core/lib/security/credentials/credentials.h"
 #include "src/core/util/crash.h"
 #include "src/core/util/env.h"
 #include "src/proto/grpc/testing/duplicate/echo_duplicate.grpc.pb.h"
@@ -60,7 +61,8 @@
 #include "src/core/lib/iomgr/ev_posix.h"
 #endif  // GRPC_POSIX_SOCKET_EV
 
-#include <gtest/gtest.h>
+#include "gmock/gmock.h"
+#include "gtest/gtest.h"
 
 using std::chrono::system_clock;
 
@@ -1514,14 +1516,13 @@ TEST_P(End2endTest, ExpectErrorTest) {
     EXPECT_EQ(iter->code(), s.error_code());
     EXPECT_EQ(iter->error_message(), s.error_message());
     EXPECT_EQ(iter->binary_error_details(), s.error_details());
-    EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "created"));
-#ifndef NDEBUG
-    // grpc_core::StatusIntProperty::kFileLine is for debug only
-    EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "file"));
-    EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "line"));
-#endif
-    EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "status"));
-    EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "13"));
+    if (grpc_core::IsErrorFlattenEnabled()) {
+      EXPECT_THAT(context.debug_error_string(),
+                  ::testing::HasSubstr("INTERNAL"));
+    } else {
+      EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "status"));
+      EXPECT_TRUE(absl::StrContains(context.debug_error_string(), "13"));
+    }
   }
 }
 
@@ -1699,7 +1700,7 @@ TEST_P(ProxyEnd2endTest, ServerCancelsRpc) {
   ClientContext context;
   Status s = stub_->Echo(&context, request, &response);
   EXPECT_EQ(StatusCode::CANCELLED, s.error_code());
-  EXPECT_TRUE(s.error_message().empty());
+  EXPECT_EQ(s.error_message(), "");
 }
 
 // Make the response larger than the flow control window.
