@@ -17,7 +17,6 @@
 //
 
 #include <address_sorting/address_sorting.h>
-#include <gmock/gmock.h>
 #include <grpc/grpc.h>
 #include <grpc/support/alloc.h>
 #include <grpc/support/string_util.h>
@@ -30,6 +29,7 @@
 
 #include "absl/log/check.h"
 #include "absl/log/log.h"
+#include "gmock/gmock.h"
 #include "src/core/client_channel/client_channel_filter.h"
 #include "src/core/config/config_vars.h"
 #include "src/core/lib/address_utils/sockaddr_utils.h"
