@@ -45,3 +45,15 @@ tools/bazel \
     -- \
     //test/core/config:all \
     //test/cpp/common:all
+
+# Test if public targets are buildable with openssl and without dev
+# dependencies.
+tools/bazel \
+    build \
+    --enable_bzlmod=true \
+    --enable_workspace=false \
+    --ignore_dev_dependency \
+    --//third_party:grpc_use_openssl=true \
+    -- \
+    :all \
+    -:grpcpp_csm_observability  # Needs google_cloud_cpp to be added to BCR
